@@ -374,6 +374,8 @@ func (mg *MachineGuest) ToSize() string {
 		return "a100-40gb"
 	case mg.GPUKind == "a100-sxm4-80gb":
 		return "a100-80gb"
+	case mg.GPUKind == "l40s":
+		return "l40s"
 	case mg.CPUKind == "shared":
 		return fmt.Sprintf("shared-cpu-%dx", mg.CPUs)
 	case mg.CPUKind == "performance":
@@ -421,6 +423,7 @@ var MachinePresets map[string]*MachineGuest = map[string]*MachineGuest{
 
 	"a100-40gb": {GPUKind: "a100-pcie-40gb", CPUKind: "performance", CPUs: 8, MemoryMB: 16 * MIN_MEMORY_MB_PER_CPU},
 	"a100-80gb": {GPUKind: "a100-sxm4-80gb", CPUKind: "performance", CPUs: 8, MemoryMB: 16 * MIN_MEMORY_MB_PER_CPU},
+	"l40s":      {GPUKind: "l40s", CPUKind: "performance", CPUs: 8, MemoryMB: 16 * MIN_MEMORY_MB_PER_CPU},
 }
 
 type MachineMetrics struct {
