@@ -1,6 +1,8 @@
 package appconfig
 
-import "context"
+import (
+	"context"
+)
 
 type contextKeyType int
 
