@@ -398,7 +398,7 @@ func Region(ctx context.Context, splitPaid bool, params RegionParams) (*api.Regi
 
 		for _, region := range paidOnly {
 			if slug == region.Code {
-				return nil, fmt.Errorf("region %s requires an organization with a paid plan. See our plans: https://fly.io/plans", slug)
+				return nil, fmt.Errorf("region %s requires an organization with a Launch plan or higher. See our plans: https://fly.io/plans", slug)
 			}
 		}
 
@@ -437,7 +437,7 @@ func SelectRegion(ctx context.Context, msg string, paid []api.Region, regions []
 	var options []string
 	if isInteractive(ctx) && len(paid) > 0 {
 		io := iostreams.FromContext(ctx)
-		fmt.Fprintf(io.ErrOut, "Some regions require a paid plan (%s).\nSee https://fly.io/plans to set up a plan.\n\n", strings.Join(lo.Map(paid, func(r api.Region, _ int) string { return r.Code }), ", "))
+		fmt.Fprintf(io.ErrOut, "Some regions require a Launch plan or higher (%s).\nSee https://fly.io/plans to set up a plan.\n\n", strings.Join(lo.Map(paid, func(r api.Region, _ int) string { return r.Code }), ", "))
 	}
 
 	for _, r := range regions {
@@ -469,7 +469,7 @@ func MultiSelectRegion(ctx context.Context, msg string, paid []api.Region, regio
 
 	if isInteractive(ctx) && len(paid) > 0 {
 		io := iostreams.FromContext(ctx)
-		fmt.Fprintf(io.ErrOut, "Some regions require a paid plan (%s).\nSee https://fly.io/plans to set up a plan.\n\n", strings.Join(lo.Map(paid, func(r api.Region, _ int) string { return r.Code }), ", "))
+		fmt.Fprintf(io.ErrOut, "Some regions require a Launch plan or higher (%s).\nSee https://fly.io/plans to set up a plan.\n\n", strings.Join(lo.Map(paid, func(r api.Region, _ int) string { return r.Code }), ", "))
 	}
 
 	for i, r := range regions {
