@@ -11,8 +11,8 @@ import (
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/gql"
 	"github.com/superfly/flyctl/internal/buildinfo"
+	"github.com/superfly/flyctl/internal/logger"
 	"github.com/superfly/flyctl/iostreams"
-	"github.com/superfly/flyctl/logger"
 )
 
 func main() {
@@ -28,7 +28,7 @@ func run() error {
 		apiClient = api.NewClientFromOptions(api.ClientOptions{
 			AccessToken: os.Getenv("FLY_PREFLIGHT_TEST_ACCESS_TOKEN"),
 			Name:        buildinfo.Name(),
-			Version:     buildinfo.ParsedVersion().String(),
+			Version:     buildinfo.Version().String(),
 			BaseURL:     "https://api.fly.io",
 			Logger:      logger.FromEnv(iostreams.System().ErrOut),
 		})
