@@ -4,18 +4,16 @@
 package preflight
 
 import (
+	"slices"
 	"testing"
 
 	"github.com/stretchr/testify/require"
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/test/preflight/testlib"
-	"golang.org/x/exp/slices"
 )
 
 // test --port and --autostart --autostop flags
 func TestFlyMachineRun_autoStartStop(t *testing.T) {
-	t.Parallel()
-
 	f := testlib.NewTestEnvFromEnv(t)
 	appName := f.CreateRandomAppMachines()
 
@@ -69,8 +67,6 @@ func TestFlyMachineRun_autoStartStop(t *testing.T) {
 
 // test --standby-for
 func TestFlyMachineRun_standbyFor(t *testing.T) {
-	t.Parallel()
-
 	f := testlib.NewTestEnvFromEnv(t)
 	appName := f.CreateRandomAppMachines()
 
@@ -133,8 +129,6 @@ func TestFlyMachineRun_standbyFor(t *testing.T) {
 
 // test --port (add, update, remove services and ports)
 func TestFlyMachineRun_port(t *testing.T) {
-	t.Parallel()
-
 	f := testlib.NewTestEnvFromEnv(t)
 	appName := f.CreateRandomAppMachines()
 
@@ -154,9 +148,6 @@ func TestFlyMachineRun_port(t *testing.T) {
 	require.Equal(f, want, m.Config.Services)
 	require.Contains(f, []string{"created", "started"}, m.State)
 
-	result := f.Fly("dig %s.internal -a %s --short", appName, appName)
-	require.NotEmpty(f, result.StdOut().String())
-
 	f.Fly("machine update -a %s %s -y --port 80/tcp:http --port 1001/udp", appName, m.ID)
 	m = f.MachinesList(appName)[0]
 	want = []api.MachineService{{
